@@ -252,7 +252,7 @@ class Accessory(models.Model):
 
     @property
     def has_data_transformer(self):
-        return hasattr(self, 'datatransformer_set') or hasattr(self, 'data_transformer_set')
+        return self.datatransformer_set.count() > 0
 
     @property
     def datatransformer(self):
@@ -312,7 +312,7 @@ class DataTransformer(MPTTModel):
     accessory = models.ForeignKey(
         Accessory,
         on_delete=models.CASCADE,
-        blank = False,
+        blank = True,
         null=False
     )
     type = models.CharField(max_length=255,  blank=True, null=True, default=None)
@@ -332,8 +332,6 @@ class DataTransformer(MPTTModel):
             models.Index(fields=['id','accessory']),
         ]
 
-    class MPTTMeta:
-        order_insertion_by=['']
 
 
 class DataTransformerConstants(models.Model):
